==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-mainmenu/translations/mainmenu_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="113"/>
        <source>Search...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="123"/>
        <source>Show/hide main menu</source>
        <translation>Mostra/nascondi menu principale</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="522"/>
        <source>Add to desktop</source>
        <translation>Aggiungi al desktop</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="530"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="531"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Un file dello stesso nome esiste già.
Sovrascriverlo?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="537"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="538"/>
        <source>The file cannot be overwritten.</source>
        <translation>Impossibile sovrascrivere il file.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="544"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Impostazioni del menu principale di LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Testo del pulsante:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Dimensione personalizzata del carattere:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>File del menu:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>Dimensione massima:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Mostra risultati:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>Numero massimo:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtra le categorie</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Nascondi menu durante la ricerca</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Pulisci campo di ricerca dopo azione</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoia da tastiera</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Fai clic sul pulsante per impostare una scorciatoia:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>Seleziona file icona</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>File immagini (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>Selezione file del menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>File di menu (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-mainmenu/translations/mainmenu_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="108"/>
        <source>Search...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="118"/>
        <source>Show/hide main menu</source>
        <translation>Mostra/nascondi menu principale</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="467"/>
        <source>Add to desktop</source>
        <translation>Aggiungi al desktop</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="475"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="476"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Un file dello stesso nome esiste già.
Sovrascriverlo?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="482"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="483"/>
        <source>The file cannot be overwritten.</source>
        <translation>Impossibile sovrascrivere il file.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="489"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu Settings</source>
        <translation>Impostazioni del menu principale di LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="26"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="50"/>
        <source>Button text:</source>
        <translation>Testo del pulsante:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="67"/>
        <source>Custom font size:</source>
        <translation>Dimensione personalizzata del carattere:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="77"/>
        <source> pt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="96"/>
        <source>Menu file</source>
        <translation>File del menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="102"/>
        <source>Menu file:</source>
        <translation>File del menu:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="147"/>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="181"/>
        <source>Max. item width:</source>
        <translation>Dimensione massima:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="160"/>
        <source>Show matching entries:</source>
        <translation>Mostra risultati:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="167"/>
        <source>Maximum visible items:</source>
        <translation>Numero massimo:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="153"/>
        <source>Filter menu entries</source>
        <translation>Filtra le categorie</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="188"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="201"/>
        <source>Hide menu entries while searching</source>
        <translation>Nascondi menu durante la ricerca</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="208"/>
        <source>Clear search upon showing menu</source>
        <translation>Cancella la ricerca quando viene visualizzato il menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="118"/>
        <source>Keyboard Shortcut</source>
        <translation>Scorciatoia da tastiera</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="124"/>
        <source>Click the button to record shortcut:</source>
        <translation>Fai clic sul pulsante per impostare una scorciatoia:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>Ripristina</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>Seleziona file icona</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>File immagini (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>Selezione file del menu</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>File di menu (*.menu)</translation>
    </message>
</context>
</TS>
